function clip(info, tab) {
  var body;
  var page;

  if (info.selectionText) {
    body = info.selectionText;
    page = false;
  } else if (info.pageUrl) {
    body = info.pageUrl;
    page = true;
  }

  chrome.tabs.query({ active: true, currentWindow: true }, (tabs) => {
    chrome.tabs.sendMessage(
      tabs[0].id,
      {
        msg: "select_project",
        data: {
          body: body,
          title: tab.title,
          page: page
        }
      }
    )
  });  
}

function createVoicepod(data) {
  var expiry = localStorage.getItem("_voicepods_expiry");
  var accessToken = localStorage.getItem("_voicepods_accessToken");
  var uid = localStorage.getItem("_voicepods_uid");
  var client = localStorage.getItem("_voicepods_client");
  
  var project_id = data.selected_project;
  var title = data.page_title;
  var body = data.body;
  var page = data.page;
  var voice = data.voice;

  var headers = {
    expiry: expiry,
    'access-token': accessToken,
    uid: uid,
    client: client,
    'token-type': 'Bearer'
  }

  $.ajax({
    // url: 'http://localhost:3000/api/v1/projects/' + project_id + '/pods',
    url: 'https://app.voicepods.com/api/v1/projects/' + project_id + "/pods",
    headers: headers,
    method: 'POST',
    dataType: 'json',
    data: {
      page: page,
      data: {
        title: title,
        body: body,
        voice: voice,
      }
    },
    success: (data) => {
      if (data.status === "FAILED") {
        chrome.tabs.query({ active: true, currentWindow: true }, (tabs) => {
          chrome.tabs.sendMessage(
            tabs[0].id,
            {
              msg: "failed_conversion",
              data: {
                status: data.status,
                reason: data.reason,
              }
            }
          )
        });
      } else {
        console.log('success: ' + data);
      }
    }
  });
}

chrome.runtime.onMessage.addListener(
  function (request, sender, sendResponse) {
    if (request.msg === "login_successful") {
      localStorage.setItem("_voicepods_uid", request.data.uid);
      localStorage.setItem("_voicepods_accessToken", request.data.accessToken);
      localStorage.setItem("_voicepods_expiry", request.data.expiry);
      localStorage.setItem("_voicepods_client", request.data.client);
    } else if (request.msg === "add_to_project") {
      console.log(request);
      console.log("add_to_project");
      createVoicepod(request.data);
    }
  }
);

var clipTextTitle = "Convert selection to Speech",
    clipPageTitle = "Convert page to Speech";

chrome.contextMenus.create({
  title: clipTextTitle,
  onclick: clip,
  contexts: ["selection"]
});

chrome.contextMenus.create({
  title: clipPageTitle,
  onclick: clip,
  contexts: ["page"]
});
