"use strict";

chrome.runtime.onMessage.addListener(
  function(event, tab, response_callback) {
    if (event["msg"] === "select_project") {
      var page_title = event["data"]["title"];
      var body = event["data"]["body"];
      var page = event["data"]["page"];

      // Read it using the storage API
      chrome.storage.sync.get(['uid', 'client', 'accessToken', 'expiry', 'projects'], (items) => {
        var expiry = items.expiry;
        var accessToken = items.accessToken;
                
        if (!expiry) {
          alert("You need to login to Voicepods. Click the Voicepods icon in your toolbar to get started.");
          return;
        }

        var milliseconds = (new Date).getTime() / 1000;
        
        if (!accessToken || milliseconds >= expiry) {
          alert("Please login again by clicking on the Voicepods icon in your toolbar.");
          return;
        }

        var projects = JSON.parse(items.projects);

        fetch(chrome.extension.getURL('/confirmation.html'))
          .then(response => response.text())
          .then((data) => {

            var inject = document.createElement("div");
            inject.innerHTML = data;
            document.body.insertBefore(inject, document.body.firstChild);
            
            var select = document.getElementById('VoicepodsProjectSelect');

            for (var project of projects) {
              var opt = document.createElement('option');
              opt.value = project.id;
              opt.innerHTML = project.name;
              select.appendChild(opt);
            }

            // handlers for create and dismiss
            document.getElementById("VoicepodsCreate").addEventListener("click", () => {
              // Create Pod
              var selected_value = select.options[select.selectedIndex].value
              var voice = document.getElementById('VoicepodsVoiceSelect');
              var voice_value = voice.options[voice.selectedIndex].value

              chrome.runtime.sendMessage({
                msg: 'add_to_project',
                data: {
                  selected_project: selected_value,
                  voice: voice_value,
                  body: body,
                  page_title: page_title,
                  page: page
                }
              })

              var element = document.getElementById("VoicepodsConfirmation");
              element.parentNode.removeChild(element);
            });

            document.getElementById("VoicepodsDismiss").addEventListener("click", () => {
              // remove injected element
              var element = document.getElementById("VoicepodsConfirmation");
              element.parentNode.removeChild(element);
            });

          }).catch(err => {
            // handle error
            alert("Oops. Something went wrong!");
          });
      });
    } else if (event["msg"] === "failed_conversion") {
      if (event["data"].reason === "exceeded limit") {
        swal({
          title: '<strong>Exceeded Limit!</strong>',
          type: 'info',
          html:
            "You've exceeded the limits of pods you can create! " +
            '<a href="https://app.voicepods.com/">Visit Voicepods</a> ' +
            'to upgrade.',
          confirmButtonText:
            '<i class="fa fa-thumbs-up"></i>Confirm',
          confirmButtonAriaLabel: 'Confirm',
        });
      } else {
        alert("Oops, looks like we couldn't convert that. Try again later.");
      }
    }
  }
);
